Struct BootSpecification
Source #[repr(C, packed(1))]
pub struct BootSpecification {
pub header: DevicePathProtocol,
pub device_type: u16,
pub status_flag: u16,
pub description_string: [u8; 0],
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.